@@ -198,16 +198,17 @@ class ImportScanSerializer(Schema):
     service = fields.Str(required=False)
     group_by = fields.Str(required=False)
     test_title = fields.Str(required=False)
-    description_product = fields.Str(required=False)
+    product_description = fields.Str(required=False)
     create_finding_groups_for_all_findings = fields.Str(required=False)
     tools_configuration = fields.Int(required=False, load_default=1)
     code_app = fields.Str(required=False)
     # defect-dojo credential
-    token_cmdb = fields.Str(required=True)
-    host_cmdb = fields.Url(required=True)
+    token_cmdb = fields.Str(required=False)
+    host_cmdb = fields.Url(required=False)
+    cmdb_request_response = fields.Dict(required=False)
     token_defect_dojo = fields.Str(required=True)
     host_defect_dojo = fields.Str(required=True)
-    cmdb_mapping = fields.Dict(required=True)
+    cmdb_mapping = fields.Dict(required=False)
     product_type_name_mapping = fields.Dict(required=False)
     # Config remote credential
     compact_remote_config_url = fields.Str(required=False)
